Kind

Enum Kind 

pub enum Kind {
    Preceding(Preceding),
    Following(Following),
    CurrentRow(CurrentRow),
    Unbounded(Unbounded),
}

Variants



Preceding(Preceding)

The bound extends some number of records behind the current record.



Following(Following)

The bound extends some number of records ahead of the current record.



CurrentRow(CurrentRow)

The bound extends to the current record.



Unbounded(Unbounded)

The bound extends to the start of the partition or the end of the partition, depending on whether this represents the upper or lower bound.

Implementations

Source

impl Kind

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Kind>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.