pub struct Preceding {
pub offset: i64,
}Expand description
Defines that the bound extends this far back from the current record.
Fields
offset: i64A strictly positive integer specifying the number of records that the window extends back from the current record. Required. Use CurrentRow for offset zero and Following for negative offsets.